@@ -41,6 +41,8 @@ func renderTemplateNoTrimSpace(env *mock.Environment, segmentTemplate string, co
 	env.On("Error", testify_.Anything)
 	env.On("Debug", testify_.Anything)
 	env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
+	env.On("Flags").Return(&runtime.Flags{})
+
 	tmpl := &template.Text{
 		Template: segmentTemplate,
 		Context:  context,
@@ -178,6 +180,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 		MaxDepth            int
 		MaxWidth            int
 		HideRootLocation    bool
+		Cygwin              bool
 	}{
 		{
 			Style:               Unique,
@@ -429,6 +432,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 			Pwd:                 "C:\\Users\\foo\\foobar\\man",
 			GOOS:                runtime.WINDOWS,
 			Shell:               shell.BASH,
+			Cygwin:              true,
 			Cygpath:             "/c/Users/foo/foobar/man",
 			PathSeparator:       "\\",
 			FolderSeparatorIcon: " > ",
@@ -764,6 +768,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 		env.On("Home").Return(tc.HomePath)
 		env.On("Pwd").Return(tc.Pwd)
 		env.On("GOOS").Return(tc.GOOS)
+		env.On("IsCygwin").Return(tc.Cygwin)
 		env.On("StackCount").Return(0)
 		env.On("IsWsl").Return(false)
 		args := &runtime.Flags{
@@ -778,7 +783,7 @@ func TestAgnosterPathStyles(t *testing.T) {
 
 		env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
 
-		displayCygpath := tc.GOOS == runtime.WINDOWS && tc.Shell == shell.BASH
+		displayCygpath := tc.Cygwin
 		if displayCygpath {
 			env.On("RunCommand", "cygpath", []string{"-u", tc.Pwd}).Return(tc.Cygpath, tc.CygpathError)
 			env.On("RunCommand", "cygpath", testify_.Anything).Return("brrrr", nil)
@@ -1013,6 +1018,8 @@ func TestPowerlevelMappedLocations(t *testing.T) {
 		env.On("PathSeparator").Return("/")
 		env.On("Shell").Return(shell.GENERIC)
 		env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
+		env.On("Flags").Return(&runtime.Flags{})
+
 		path := &Path{
 			env: env,
 			props: properties.Map{
@@ -1020,8 +1027,10 @@ func TestPowerlevelMappedLocations(t *testing.T) {
 				MappedLocations:  tc.MappedLocations,
 			},
 		}
+
 		path.setPaths()
 		path.setStyle()
+
 		got := renderTemplateNoTrimSpace(env, "{{ .Path }}", path)
 		assert.Equal(t, tc.Expected, got)
 	}
@@ -1462,6 +1471,8 @@ func TestGetFolderSeparator(t *testing.T) {
 		env.On("Error", testify_.Anything)
 		env.On("Debug", testify_.Anything)
 		env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
+		env.On("Flags").Return(&runtime.Flags{})
+
 		path := &Path{
 			env:           env,
 			pathSeparator: "/",
@@ -1540,6 +1551,8 @@ func TestReplaceMappedLocations(t *testing.T) {
 		env.On("GOOS").Return(runtime.DARWIN)
 		env.On("Home").Return("/a/b/k")
 		env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
+		env.On("Flags").Return(&runtime.Flags{})
+
 		path := &Path{
 			env: env,
 			props: properties.Map{
@@ -1552,6 +1565,7 @@ func TestReplaceMappedLocations(t *testing.T) {
 				},
 			},
 		}
+
 		path.setPaths()
 		assert.Equal(t, tc.Expected, path.pwd)
 	}
@@ -1659,6 +1673,7 @@ func TestGetMaxWidth(t *testing.T) {
 		env := new(mock.Environment)
 		env.On("DebugF", testify_.Anything, testify_.Anything).Return(nil)
 		env.On("Error", testify_.Anything).Return(nil)
+		env.On("Flags").Return(&runtime.Flags{})
 		env.On("TemplateCache").Return(&cache.Template{
 			Env: map[string]string{
 				"MAX_WIDTH": "120",
